@@ -30,6 +30,8 @@ from osducli.commands.config.consts import (
     MSG_PROMPT_CLIENT_ID,
     MSG_PROMPT_CLIENT_SECRET,
     MSG_PROMPT_CONFIG_ENTITLEMENTS_URL,
+    MSG_PROMPT_CRS_CATALOG_URL,
+    MSG_PROMPT_CRS_CONVERTER_URL,
     MSG_PROMPT_DATA_PARTITION,
     MSG_PROMPT_FILE_URL,
     MSG_PROMPT_LEGAL_TAG,
@@ -54,6 +56,8 @@ from osducli.config import (
     CONFIG_AUTHENTICATION_SCOPES,
     CONFIG_CLIENT_ID,
     CONFIG_CLIENT_SECRET,
+    CONFIG_CRS_CATALOG_URL,
+    CONFIG_CRS_CONVERTER_URL,
     CONFIG_DATA_PARTITION_ID,
     CONFIG_ENTITLEMENTS_URL,
     CONFIG_FILE_URL,
@@ -198,6 +202,19 @@ def _configure_authentication(config):
 def _configure_connection(config):  # noqa C901 pylint: disable=R0912
     server = _prompt_default_from_config(MSG_PROMPT_SERVER, config, CONFIG_SERVER)
 
+    crs_catalog_url = _prompt_default_from_config(
+        MSG_PROMPT_CRS_CATALOG_URL,
+        config,
+        CONFIG_CRS_CATALOG_URL,
+        fallback="/api/crs/catalog/v2/",
+    )
+
+    crs_converter_url = _prompt_default_from_config(
+        MSG_PROMPT_CRS_CONVERTER_URL,
+        config,
+        CONFIG_CRS_CONVERTER_URL,
+        fallback="/api/crs/converter/v2/",
+    )
     entitlements_url = _prompt_default_from_config(
         MSG_PROMPT_CONFIG_ENTITLEMENTS_URL,
         config,
@@ -251,6 +268,10 @@ def _configure_connection(config):  # noqa C901 pylint: disable=R0912
     # save the global config
     if server != "":
         config.set_value("core", CONFIG_SERVER, server)
+    if crs_catalog_url != "":
+        config.set_value("core", CONFIG_CRS_CATALOG_URL, crs_catalog_url)
+    if crs_converter_url != "":
+        config.set_value("core", CONFIG_CRS_CONVERTER_URL, crs_converter_url)
     if entitlements_url != "":
         config.set_value("core", CONFIG_ENTITLEMENTS_URL, entitlements_url)
     if file_url != "":
