@@ -10,7 +10,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-"""Custom cluster upgrade specific commands"""
+"""Legal service list tags commands"""
 import click
 
 from osducli.click_cli import CustomClickCommand, State, command_with_output
@@ -26,10 +26,10 @@ from osducli.config import CONFIG_LEGAL_URL
 def _click_command(state: State):
     """List legal tags"""
 
-    return records(state)
+    return list_tags(state)
 
 
-def records(state: State):
+def list_tags(state: State):
     """[summary]
 
     Args:
