@@ -31,6 +31,7 @@ from osducli.commands.file._const import FILE_SERVICE_NAME, FILE_STATUS_PATH
 from osducli.commands.legal._const import LEGAL_SERVICE_NAME, LEGAL_STATUS_PATH
 from osducli.commands.schema._const import SCHEMA_SERVICE_NAME, SCHEMA_STATUS_PATH
 from osducli.commands.search._const import SEARCH_SERVICE_NAME, SEARCH_STATUS_PATH
+from osducli.commands.storage._const import STORAGE_SERVICE_NAME, STORAGE_STATUS_PATH
 from osducli.commands.unit._const import UNIT_SERVICE_NAME, UNIT_STATUS_PATH
 from osducli.commands.workflow._const import WORKFLOW_SERVICE_NAME, WORKFLOW_STATUS_PATH
 from osducli.config import (
@@ -76,7 +77,7 @@ def status(state: State):  # pylint: disable=unused-argument
         (LEGAL_SERVICE_NAME, CONFIG_LEGAL_URL, LEGAL_STATUS_PATH),
         (SCHEMA_SERVICE_NAME, CONFIG_SCHEMA_URL, SCHEMA_STATUS_PATH),
         (SEARCH_SERVICE_NAME, CONFIG_SEARCH_URL, SEARCH_STATUS_PATH),
-        ("Storage service", CONFIG_STORAGE_URL, "health"),
+        (STORAGE_SERVICE_NAME, CONFIG_STORAGE_URL, STORAGE_STATUS_PATH),
         (UNIT_SERVICE_NAME, CONFIG_UNIT_URL, UNIT_STATUS_PATH),
         (WORKFLOW_SERVICE_NAME, CONFIG_WORKFLOW_URL, WORKFLOW_STATUS_PATH),
     ]
